beamprofiler.iso.characterizing\_parameters.flatness\_factor
============================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: flatness_factor